@@ -1,7 +1,7 @@
 package Acme::CPANModules::PortedFrom::NPM;
 
-our $DATE = '2021-03-13'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-03-15'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
     summary => "Modules/applications that are ported (or inspired from) NPM libraries",
@@ -11,6 +11,11 @@ If you know of others, please drop me a message.
 
 _
     entries => [
+        {
+            module => 'App::AsciiChart',
+            npm_module => 'asciichart',
+            tags => ['cli', 'chart'],
+        },
         {
             module => 'App::chalk',
             npm_module => 'chalk',
@@ -49,7 +54,7 @@ Acme::CPANModules::PortedFrom::NPM - Modules/applications that are ported (or in
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::PortedFrom::NPM (from Perl distribution Acme-CPANModules-PortedFrom-NPM), released on 2021-03-13.
+This document describes version 0.003 of Acme::CPANModules::PortedFrom::NPM (from Perl distribution Acme-CPANModules-PortedFrom-NPM), released on 2021-03-15.
 
 =head1 DESCRIPTION
 
@@ -59,6 +64,8 @@ If you know of others, please drop me a message.
 
 =over
 
+=item * L<App::AsciiChart>
+
 =item * L<App::chalk>
 
 =item * L<App::envset>
@@ -115,6 +122,12 @@ feature.
 
 =head1 SEE ALSO
 
+More on the same theme of modules ported from other languages:
+L<Acme::CPANModules::PortedFrom::Java>,
+L<Acme::CPANModules::PortedFrom::PHP>,
+L<Acme::CPANModules::PortedFrom::Python>,
+L<Acme::CPANModules::PortedFrom::Ruby>.
+
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
 
 L<cpanmodules> - CLI tool to let you browse/view the lists
